Wireworld is a cellular automaton with some similarities to Conway's Game of Life.
It is capable of doing sophisticated computations with appropriate programs (it is actually Turing complete), and is much simpler to program for.
A wireworld arena consists of a cartesian grid of cells, each of which can be in one of four states. All cell transitions happen simultaneously.

Params::

  --size=250*10

